@@ -74,7 +74,8 @@ class CortxJupyter(ContentsManager):
         return _run_sync(file_exists_async)
 
     def get(self, path, content=True, type=None, format=None):
-
+        print('TESTING GET')
+        print(path,content,type,format)
         @gen.coroutine
         def get_async():
             return (yield _get_model(self._config(), path, content, type, format))
