@@ -226,9 +226,9 @@ def _get_notebook(config, path, content):
 @gen.coroutine
 def _get_folder(config, path, content):
     key = _get_key(config, path)
-    prefix = key if (key == '' or key[-1] == '/') else (key + '/')
+    key_prefix = key if (key == '' or key[-1] == '/') else (key + '/')
     keys, directories = \
-        (yield _list_current_child_files_and_folders(config, prefix)) if content else \
+        (yield _list_current_child_files_and_folders(config, key_prefix)) if content else \
         ([], [])
 
     all_keys = {key for (key, _) in keys}
@@ -407,8 +407,8 @@ def _create_new_checkpoint(config, path):
 
 @gen.coroutine
 def _list_all_checkpoints(config, path):
-    prefix = _get_key(config, path + '/' + CHECKPOINT_NAME + '/')
-    keys, _ = yield _list_current_child_files_and_folders(config, prefix)
+    key_prefix = _get_key(config, path + '/' + CHECKPOINT_NAME + '/')
+    keys, _ = yield _list_current_child_files_and_folders(config, key_prefix)
     return [
         {
             'id': key[(key.rfind('/' + CHECKPOINT_NAME + '/') + len('/' + CHECKPOINT_NAME + '/')):],
@@ -538,12 +538,12 @@ def _delete__notebook_checkpoint(config, checkpoint_id, path):
 
 
 @gen.coroutine
-def _list_current_child_files_and_folders(config, prefix):
-    return (yield _get_all_keys(config, prefix, '/'))
+def _list_current_child_files_and_folders(config, key_prefix):
+    return (yield _get_all_keys(config, key_prefix, '/'))
 
 @gen.coroutine
-def _list_all_successor_keys(config, prefix):
-    return (yield _get_all_keys(config, prefix, ''))[0]
+def _list_all_successor_keys(config, key_prefix):
+    return (yield _get_all_keys(config, key_prefix, ''))[0]
 
 @gen.coroutine
 def _restore_notebook_checkpoint(config, checkpoint_id, path):
@@ -602,18 +602,18 @@ def _copy_notebook(config, from_path, to_path):
 
 
 @gen.coroutine
-def _get_all_keys(config, prefix, delimiter):
+def _get_all_keys(config, key_prefix, delimiter):
 
     max_keys = 1000
 
     @gen.coroutine
-    def _list_home_page():
-        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys)
+    def _list_first_page():
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys)
         return _parse_list_response(response)
 
     @gen.coroutine
-    def _list_next_page(token):
-        response = yield _list_objects(config, config.bucket_name, prefix, delimiter, max_keys, token)
+    def _list_later_page(token):
+        response = yield _list_objects(config, config.bucket_name, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
@@ -639,17 +639,15 @@ def _get_all_keys(config, prefix, delimiter):
             next_token = response['NextContinuationToken']
         return (next_token, keys, directories)
 
-    token, keys, directories = yield _list_home_page()
+    token, keys, directories = yield _list_first_page()
 
     while token:
-        token, keys_page, directories_page = yield _list_next_page(token)
+        token, keys_page, directories_page = yield _list_later_page(token)
         keys.extend(keys_page)
         directories.extend(directories_page)
 
     return keys, directories
 
-
-#------------------------------------------
 READ_HELPERS = {
 ('directory', 'json'): _get_folder,
 ('notebook', 'json'): _get_notebook,
@@ -663,11 +661,12 @@ PUT_HELPERS = {
     ('directory', 'json'): _save_folder,
     ('file', 'text'): _save_text_file
 }
-
+#------------------------------------------
 @gen.coroutine
 def _delete_key_object(config, curr_key):
     yield _delete_object(config, config.bucket_name, curr_key)
 
+
 @gen.coroutine
 def _copy_key_object(config, prev_key, curr_key):
     yield _copy_object(config, config.bucket_name, prev_key, curr_key)
